pub struct GraphRunRecord {
pub definition: String,
pub requested_at_ms: u64,
pub state: GraphRunState,
}Expand description
The record of a graph run for one partition.
Fields
definition: StringThe definition hash the run records.
requested_at_ms: u64The time of the request, in milliseconds from the Unix epoch.
state: GraphRunStateThe state.
Implementations