The identity of a task instance: the graph, the partition, the node and
the rerun count, which together form the run id and the swale. headers
of the run.
Structs
- Task
Identity - The identity of one task instance.
Enums
- Identity
Error - The headers of a run do not identify a task instance.
Constants
- HEADER_
ASSET - Header with the asset name, present on an asset node only.
- HEADER_
DEFINITION - Header with the definition hash the graph run records.
- HEADER_
GRAPH - Header with the graph name.
- HEADER_
NODE - Header with the node name.
- HEADER_
PARTITION - Header with the partition key.
- HEADER_
RERUN - Header with the rerun count.
Functions
- run_id
- The run id
{graph}-{partition}-{node}-r{rerun}of a task instance. The graph and node names are bounded by the graph checks so that the id is within the runtime’s limit.